<?php 
/**
 * Plugin Name: Group Permissions (Matomo Plugin)
 * Plugin URI: http://plugins.matomo.org/GroupPermissions
 * Description: Manage user permissions with groups.
 * Author: Michael Roosz
 * Author URI: https://github.com/MichaelRoosz/plugin-GroupPermissions
 * Version: 5.1.1
 */
?><?php

/**
 * Matomo - free/libre analytics platform
 *
 * @link http://matomo.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 *
 */

namespace Piwik\Plugins\GroupPermissions;

use Piwik\Plugin;

 
if (defined( 'ABSPATH')
&& function_exists('add_action')) {
    $path = '/matomo/app/core/Plugin.php';
    if (defined('WP_PLUGIN_DIR') && WP_PLUGIN_DIR && file_exists(WP_PLUGIN_DIR . $path)) {
        require_once WP_PLUGIN_DIR . $path;
    } elseif (defined('WPMU_PLUGIN_DIR') && WPMU_PLUGIN_DIR && file_exists(WPMU_PLUGIN_DIR . $path)) {
        require_once WPMU_PLUGIN_DIR . $path;
    } else {
        return;
    }
    add_action('plugins_loaded', function () {
        if (function_exists('matomo_add_plugin')) {
            matomo_add_plugin(__DIR__, __FILE__, true);
        }
    });
}

class GroupPermissions extends Plugin {
    public function install(): void {
        $model = new Model();
        $model->install();
    }

    public function uninstall(): void {
        $model = new Model();
        $model->uninstall();
    }

    /**
     * @see Piwik\Plugin::registerEvents
     *
     * @return array<string, string>
     */
    public function registerEvents(): array {
        return [
            'AssetManager.getStylesheetFiles'        => 'getStylesheetFiles',
            'SitesManager.deleteSite.end'            => 'deleteSite',
            'UsersManager.deleteUser'                => 'deleteUser',
            'Translate.getClientSideTranslationKeys' => 'getClientSideTranslationKeys',
        ];
    }

    /**
     * Return list of plug-in specific Stylesheet files to be imported by the asset manager
     *
     * @see Piwik\AssetManager
     *
     * @param array<string> $stylesheetFiles
     */
    public function getStylesheetFiles(array &$stylesheetFiles): void {
        $stylesheetFiles[] = 'plugins/GroupPermissions/stylesheets/vue-multiselect.css';
        $stylesheetFiles[] = 'plugins/GroupPermissions/stylesheets/groupPermissions.less';
    }

    /**
     * @param array<string> $translations
     */
    public function getClientSideTranslationKeys(array &$translations): void {
        $translations[] = 'GroupPermissions_AddUserToGroup';
        $translations[] = 'GroupPermissions_AddUserToGroupButton';
        $translations[] = 'GroupPermissions_ChangeAccessToAllSitesConfirm';
        $translations[] = 'GroupPermissions_CreateNewGroup';
        $translations[] = 'GroupPermissions_CreateNewGroupButton';
        $translations[] = 'GroupPermissions_DeleteGroup';
        $translations[] = 'GroupPermissions_DeleteGroupButton';
        $translations[] = 'GroupPermissions_DeleteGroupConfirm';
        $translations[] = 'GroupPermissions_DescriptionAccessTab';
        $translations[] = 'GroupPermissions_DescriptionGroupsTab';
        $translations[] = 'GroupPermissions_ExceptionGroupDoesExist';
        $translations[] = 'GroupPermissions_ExceptionGroupDoesNotExist';
        $translations[] = 'GroupPermissions_ExceptionUserAlreadyInGroup';
        $translations[] = 'GroupPermissions_Group';
        $translations[] = 'GroupPermissions_GroupPermissions';
        $translations[] = 'GroupPermissions_ManageAccess';
        $translations[] = 'GroupPermissions_ManageGroup';
        $translations[] = 'GroupPermissions_ManageGroupMembers';
        $translations[] = 'GroupPermissions_ManageGroups';
        $translations[] = 'GroupPermissions_MenuGroupPermissions';
        $translations[] = 'GroupPermissions_RemoveFromGroup';
        $translations[] = 'GroupPermissions_RemoveFromGroupConfirm';
        $translations[] = 'GroupPermissions_RenameGroup';
        $translations[] = 'GroupPermissions_RenameGroupButton';
        $translations[] = 'GroupPermissions_RenameGroupConfirm';
        $translations[] = 'GroupPermissions_SelectNewUser';

        $translations[] = 'UsersManager_ApplyToAllWebsites';
        $translations[] = 'UsersManager_PrivNone';
        $translations[] = 'UsersManager_PrivView';
        $translations[] = 'UsersManager_PrivWrite';
        $translations[] = 'UsersManager_PrivAdmin';

        $translations[] = 'General_Username';
        $translations[] = 'General_Yes';
        $translations[] = 'General_No';
    }

    /**
     * Delete group preferences associated with a particular site
     */
    public function deleteSite(int $idSite): void {
        $model = new Model();
        $model->removeAllPermissionsForSite($idSite);
    }

    /**
     * Delete group preferences associated with a particular user
     */
    public function deleteUser(string $login): void {
        $model = new Model();
        $model->removeUserFromAllGroups($login);
    }
}
